==> loadmychunks-1.2.0%2B1.16.5%2Bfabric-sources.jar: com/drathonix/loadmychunks/common/registry/custom/LoaderTypeRegistry.java <==
package com.drathonix.loadmychunks.common.registry.custom;

import com.mojang.serialization.Lifecycle;
import net.minecraft.class_2370;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import com.drathonix.loadmychunks.common.registry.LoaderType;
import com.drathonix.loadmychunks.common.registry.LoaderTypeKeys;
import com.drathonix.loadmychunks.common.system.loaders.IChunkLoader;
import com.drathonix.loadmychunks.common.system.loaders.PlacedChunkLoader;
import com.drathonix.loadmychunks.common.system.loaders.extension.PlacedExtensionChunkLoader;
import com.drathonix.loadmychunks.common.util.ModResource;

/**
 * Registration location for all chunk loader types.
 */
public class LoaderTypeRegistry extends class_2370<LoaderType<?>> {
    public static final class_5321<class_2378<LoaderType<?>>> KEY = class_5321.method_29180(ModResource.of("loader_type"));
    public static final LoaderTypeRegistry INSTANCE = new LoaderTypeRegistry();

    public static final LoaderType<PlacedChunkLoader> PLACED_TYPE = register(LoaderTypeKeys.PLACED_LOADER,new LoaderType<>(PlacedChunkLoader::new));
    public static final LoaderType<PlacedExtensionChunkLoader> PLACED_EXTENSION_TYPE = register(LoaderTypeKeys.PLACED_EXTENSION_LOADER,new LoaderType<>(PlacedExtensionChunkLoader::new));

    private LoaderTypeRegistry() {
        //? if >=1.19.4 {
        /*super(KEY, Lifecycle.stable(),true);
        *///?} else if >=1.18.2 {
        /*super(KEY, Lifecycle.stable(),t->t.holder);
         *///?} else if >1.16.5 {
        /*super(KEY, Lifecycle.stable(),true);
         *///?} else {
        super(KEY, Lifecycle.stable());
         //?}
    }

    /**
     * Helper method for registering a new LoaderType.
     * @param id the id of the type.
     * @param type the type instance.
     * @return type param.
     * @param <T> the chunk loader class.
     */
    public static <T extends IChunkLoader> LoaderType<T> register(class_2960 id, LoaderType<T> type){
        //? if >1.20.4 {
        /*INSTANCE.register(ResourceKey.create(KEY,id), type, RegistrationInfo.BUILT_IN);
        *///?} else {
        INSTANCE.method_10272(class_5321.method_29179(KEY,id), type,Lifecycle.stable());
        //?}
        return type;
    }
}

==> loadmychunks-1.2.1%2B1.19.2%2Bfabric-sources.jar: com/drathonix/loadmychunks/common/registry/custom/LoaderTypeRegistry.java <==
package com.drathonix.loadmychunks.common.registry.custom;

import com.mojang.serialization.Lifecycle;
import net.minecraft.class_2370;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import com.drathonix.loadmychunks.common.registry.LoaderType;
import com.drathonix.loadmychunks.common.registry.LoaderTypeKeys;
import com.drathonix.loadmychunks.common.system.loaders.IChunkLoader;
import com.drathonix.loadmychunks.common.system.loaders.PlacedChunkLoader;
import com.drathonix.loadmychunks.common.system.loaders.extension.PlacedExtensionChunkLoader;
import com.drathonix.loadmychunks.common.util.ModResource;

/**
 * Registration location for all chunk loader types.
 */
public class LoaderTypeRegistry extends class_2370<LoaderType<?>> {
    public static final class_5321<class_2378<LoaderType<?>>> KEY = class_5321.method_29180(ModResource.of("loader_type"));
    public static final LoaderTypeRegistry INSTANCE = new LoaderTypeRegistry();

    public static final LoaderType<PlacedChunkLoader> PLACED_TYPE = register(LoaderTypeKeys.PLACED_LOADER,new LoaderType<>(PlacedChunkLoader::new));
    public static final LoaderType<PlacedExtensionChunkLoader> PLACED_EXTENSION_TYPE = register(LoaderTypeKeys.PLACED_EXTENSION_LOADER,new LoaderType<>(PlacedExtensionChunkLoader::new));

    private LoaderTypeRegistry() {
        //? if >=1.19.4 {
        /*super(KEY, Lifecycle.stable(),true);
        *///?} else if >=1.18.2 {
        super(KEY, Lifecycle.stable(),t->t.holder);
         //?} else if >1.16.5 {
        /*super(KEY, Lifecycle.stable(),true);
         *///?} else {
        /*super(KEY, Lifecycle.stable());
         *///?}
    }

    /**
     * Helper method for registering a new LoaderType.
     * @param id the id of the type.
     * @param type the type instance.
     * @return type param.
     * @param <T> the chunk loader class.
     */
    public static <T extends IChunkLoader> LoaderType<T> register(class_2960 id, LoaderType<T> type){
        //? if >1.20.4 {
        /*INSTANCE.register(ResourceKey.create(KEY,id), type, RegistrationInfo.BUILT_IN);
        *///?} else {
        INSTANCE.method_10272(class_5321.method_29179(KEY,id), type,Lifecycle.stable());
        //?}
        return type;
    }
}
